#! /usr/bin/env python
#
# This file is part of AIDS Maze
# Author(s): Frances Dusse and Alyssa Hart, Girlstart
# Copyright 2008
#
# Source code is derived from Girlstart's Project IT Girl Game Templates:
# http://itgirl.dreamhosters.com/itgirlgames/, http://www.girlstart.org/itgirl
# See the credits file for image sources.
#
# AIDS Maze is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# AIDS Maze is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with AIDS Maze.  If not, see <http://www.gnu.org/licenses/>.


import os, sys
import pygame
import MazeGameLayout
from MazeGameSprites import *
from pygame.locals import *
from helpers import *


BLOCK_SIZE = 50

# INITIALIZE GAME

pygame.init()
pygame.key.set_repeat(500, 30)

windowsize = windowwidth, windowheight = 1000, 700
screen = pygame.display.set_mode(windowsize)
area = screen.get_rect()
background,background_rect = load_image("background.png")

# LOAD ALL THE SPRITES

# Load the maze layout        
level = MazeGameLayout.layout()
layout = level.getLayout()
img_list = level.getSprites()
        
# Create all the sprite groups we'll need
space_sprites = pygame.sprite.Group()
pellet_sprites = pygame.sprite.Group()
block_sprites = pygame.sprite.Group()
finish_sprites = pygame.sprite.Group()
monster_sprites = pygame.sprite.RenderUpdates()
player_sprites = pygame.sprite.RenderUpdates()

# Calculate the center point of a block based on the block size and the window size
x_offset = (BLOCK_SIZE/2) + (windowwidth - BLOCK_SIZE*len(layout[0]))/2
y_offset = (BLOCK_SIZE/2) + (windowheight - BLOCK_SIZE*len(layout))/2

# Create all the sprites in locations based on the numbers in the layout matrix
for y in xrange(len(layout)):
    for x in xrange(len(layout[y])):
        centerPoint = [(x*BLOCK_SIZE)+x_offset,(y*BLOCK_SIZE+y_offset)]
        if layout[y][x]==level.BLOCK:
            block = Block(centerPoint, img_list[level.BLOCK])
            block_sprites.add(block)
        elif layout[y][x]==level.PLAYER:
            player = Player(centerPoint, img_list[level.PLAYER])
            player_sprites.add(player)
        #elif layout[y][x]==level.PELLET:
            #pellet = Pellet(centerPoint, img_list[level.PELLET])
            #pellet_sprites.add(pellet)
        elif layout[y][x]==level.SPACE:
            space = Space(centerPoint, img_list[level.SPACE])
            space_sprites.add(space)
        elif layout[y][x]==level.MONSTER:
            monster = Monster(centerPoint, img_list[level.MONSTER])
            monster_sprites.add(monster) 
            # We also need pellets where the monsters are
            #pellet = Pellet(centerPoint, img_list[level.PELLET])
            #pellet_sprites.add(pellet) 
        elif layout[y][x]==level.FINISH_LINE:
            finish = FinishLine(centerPoint)
            finish_sprites.add(finish)
            
# Start screen
#start_game=fales
#while not start_game
#    for event in pygame.event.get():
 #       if event.type=pygame.QUIT:
  #          sys.exit()#if the user closed the window, wuit the game
   #     elif event.type==pygame.KEYDOWN:#if the user pressed a key
    #        start_game=True
     #       
    #draw everything to the screen
    #screen.blit(background,(0,0)
    
    #font=pygame.font.Font(None, 100)
   # text=font.render("AIDS Clinic",1,(255,255,255))
    #textrect=text.get_rect()
    #textrect,centerx,textrect.centery=100/2, 700

# MAIN GAME LOOP

game_over = False
while not game_over:
    for event in pygame.event.get():
        if event.type == pygame.QUIT: 
            sys.exit()
        elif event.type == KEYDOWN:
            if ((event.key == K_RIGHT)
            or (event.key == K_LEFT)
            or (event.key == K_UP)
            or (event.key == K_DOWN)):
                player_sprites.update(event.key,block_sprites)

    monster_sprites.update(block_sprites,finish_sprites)
            
    # Check for a player/pellet collision
    eaten_pellets = pygame.sprite.spritecollide(player, pellet_sprites, True)
    player.pellets = player.pellets + len(eaten_pellets)

    # Check for a player/monster collision
    for m in pygame.sprite.spritecollide(player, monster_sprites, False):
        player.punch()
        player_sprites.draw(screen)
        pygame.display.flip()
        count=0
        while count < 200:
            for event in pygame.event.get():
                if event.type == pygame.QUIT: 
                    sys.exit()
            count=count+1
        player.notpunch()
        player_sprites.draw(screen)
        pygame.display.flip()
        game_over = False
        #n uncomment
        player.fact(background, screen)
        monster_sprites.remove(m)
    

    # Check for player/finish line collision
    if len(pygame.sprite.spritecollide(player, finish_sprites, False)) > 0:
        game_over = True
    # Check for player in dead end
    if player.dead_end(block_sprites):
        game_over=False
        
    screen.blit(background, (0,0))
    block_sprites.draw(screen)
    pellet_sprites.draw(screen)
    player_sprites.draw(screen)
    monster_sprites.draw(screen)
    finish_sprites.draw(screen)
    
    # Draw the scoreboard
    #font = pygame.font.Font("data/fonts/Gentium.ttf", 36)
    #text = font.render("Pellets Eaten: " + str(player.pellets), 1, (255, 0, 0))
    #textrect = text.get_rect()
    #textrect.top, textrect.centerx = 0, windowwidth/2
    #screen.blit(text, textrect)
    
    pygame.display.flip()
