#!/usr/bin/env python
#
# This file is part of AIDS Maze
# Author(s): Frances Dusse and Alyssa Hart, Girlstart
# Copyright 2008
#
# Source code is derived from Girlstart's Project IT Girl Game Templates:
# http://itgirl.dreamhosters.com/itgirlgames/, http://www.girlstart.org/itgirl
# See the credits file for image sources.
#
# AIDS Maze is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
#AIDS Maze is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with AIDS Maze.  If not, see <http://www.gnu.org/licenses/>.

import pygame, random
from helpers import *
from facts import *

class Player(pygame.sprite.Sprite):
    # This is our player that will move around the screen controlled by the user
    
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if True:
            self.image, self.rect = load_image('blueman3.bmp',-1)
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint
        self.oldrect=self.rect
        # Initialize the number of pellets eaten
        self.pellets = 0
        
        # Set the number of Pixels to move each time
        self.x_dist = 10
        self.y_dist = 10 
        self.index=0
        
    def punch(self):
        x=self.rect.centerx
        y=self.rect.centery
        self.image, self.rect = load_image('blueman8.png',-1)
        self.rect.centerx=x
        self.rect.centery=y
        
    def notpunch(self):
        x=self.rect.centerx
        y=self.rect.centery
        self.image, self.rect = load_image('blueman3.bmp',-1)
        self.rect.centerx=x
        self.rect.centery=y

    def fact(self, background, screen):
        screen.blit(background,(0,0))
        font=pygame.font.Font("data/fonts/Gentium.ttf", 15)
        text=font.render(fact_array[self.index], 1, (255,255,255))
        textrect=text.get_rect()
        self.index= self.index +1
        textrect.centerx, textrect.centery=500,350
        screen.blit(text, textrect)
        pygame.display.flip()

#        screen.blit(background,(0,0))
#        font = pygame.font.Font("data/fonts/Gentium.ttf", 36)
#        text = font.render("Pellets Eaten: " + str(player.pellets), 1, (255, 0, 0))
#        textrect = text.get_rect()
#        textrect.top, textrect.centerx = 0, windowwidth/2
#        screen.blit(text, textrect)
        
        answered=False
        while not answered:
            for event in pygame.event.get():
                if event.type == pygame.QUIT: 
                    sys.exit()
                elif event.type ==pygame.MOUSEBUTTONDOWN: #KEYDOWN:
      #              if (event.type=pygame.K_ENTER):
                        answered= True
        
        
    def update(self,key,block_group):
        xMove,yMove = 0,0

        if (key == K_RIGHT):
            xMove += self.x_dist
        elif (key == K_LEFT):
            xMove += -self.x_dist
        elif (key == K_UP):
            yMove += -self.y_dist
        elif (key == K_DOWN):
            yMove += self.y_dist
            

        self.rect.move_ip(xMove,yMove)

        # If we hit a block, don't move - reverse the movement
        if pygame.sprite.spritecollide(self, block_group, False):
            self.rect.move_ip(-xMove,-yMove)

    def dead_end(self,block_group):
        allowed_moves = 4

        # try moving right
        self.rect.move_ip(self.x_dist,0)
        if pygame.sprite.spritecollide(self, block_group, False): # blocked by a wall
            allowed_moves -= 1
        self.rect.move_ip(-self.x_dist,0)

        # try moving left
        self.rect.move_ip(-self.x_dist,0)
        if pygame.sprite.spritecollide(self, block_group, False): # blocked by a wall
            allowed_moves -= 1
        self.rect.move_ip(self.x_dist,0)

        # try moving up
        self.rect.move_ip(0,-self.y_dist)
        if pygame.sprite.spritecollide(self, block_group, False): # blocked by a wall
            allowed_moves -= 1
        self.rect.move_ip(0,self.y_dist)

        # try moving down
        self.rect.move_ip(0,self.y_dist)
        if pygame.sprite.spritecollide(self, block_group, False): # blocked by a wall
            allowed_moves -= 1
        self.rect.move_ip(0,-self.y_dist)

        self.oldrect=self.rect
        if allowed_moves <= 1: # blocked by a wall in at least 3 directions
            return True
        else:
            return False

class Monster(pygame.sprite.Sprite):
    # This is our Monster that will move around the screen randomly
    
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if image == None:
            self.image, self.rect = load_image('monster.png',-1)
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint

        # Initialize the direction and speed:
        self.direction = random.randint(1,4)
        self.speed = 1  # how many pixels to move each time
        self.moves = random.randint(50,100)
        self.moveCount = 0
            
    def update(self,block_group,block_group2=None):
        xMove,yMove = 0,0
        
        if self.direction==1:
            xMove = -self.speed
        elif self.direction==2:
            yMove = -self.speed
        elif self.direction==3:
            xMove = self.speed
        elif self.direction==4:
            yMove = self.speed
        
        self.rect.move_ip(xMove,yMove)
        self.moveCount += 1
        
        if pygame.sprite.spritecollideany(self, block_group) or pygame.sprite.spritecollideany(self, block_group2):
            # If we hit a block or finish line, don't move - reverse the movement
            self.rect.move_ip(-xMove,-yMove)
            self.direction = random.randint(1,4)
        elif self.moves == self.moveCount:
            # If we have moved enough, choose a new direction
            self.direction = random.randint(1,4)
            self.moves = random.randint(50,100)
            self.moveCount = 0

#class Pellet(pygame.sprite.Sprite):
        
    #def __init__(self, centerPoint, image = None):
        #pygame.sprite.Sprite.__init__(self) 
        
        #if image == None:
           # self.image, self.rect = load_image('pellet.png',-1)
        #else:
            #self.image = image
            #self.rect = image.get_rect()
        #self.rect.center = centerPoint

class Block(pygame.sprite.Sprite):
        
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if image == None:
            self.image, self.rect = load_image('block.png',-1)
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint

class Space(pygame.sprite.Sprite):
        
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if image == None:
            self.image, self.rect = load_image('space.png',-1)
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint

class FinishLine(pygame.sprite.Sprite):
        
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if image == None:
            self.image, self.rect = load_image('Clinic.bmp')
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint
